{$I UOpt.INC}				(* Standard Conditional-Defines *)
UNIT Main;

INTERFACE

USES Windows, SysUtils, Classes, Graphics, Forms, Controls, Menus,
     StdCtrls, Dialogs, Buttons, Messages, ExtCtrls, ComCtrls, Profil, Uabout;

TYPE
  TMDIMainForm = CLASS(TForm)
    MDIMainMenu: TMainMenu;
    File1: TMenuItem;
    FileNewItem: TMenuItem;
    FileOpenItem: TMenuItem;
    FileCloseItem: TMenuItem;
    Window1: TMenuItem;
    Help1: TMenuItem;
    N1: TMenuItem;
    FileExitItem: TMenuItem;
    WindowCascadeItem: TMenuItem;
    WindowTileItem: TMenuItem;
    WindowArrangeItem: TMenuItem;
    HelpAboutItem: TMenuItem;
    FileSaveItem: TMenuItem;
    FileSaveAsItem: TMenuItem;
    SpeedPanel: TPanel;
    OpenBtn: TSpeedButton;
    SaveBtn: TSpeedButton;
    ExitBtn: TSpeedButton;
    StatusBar: TStatusBar;
    INIProfile: TProfile;
    SpeedButtonPFNode: TSpeedButton;
    SpeedButtonPFWire: TSpeedButton;
    SpeedButton2: TSpeedButton;
    SpeedButtonLtg: TSpeedButton;
    SpeedButtonZL: TSpeedButton;
    SpeedButtonQuelle: TSpeedButton;
    WindowMinimizeItem: TMenuItem;
    Contents1: TMenuItem;
    PROCEDURE FormCreate(Sender: TObject);
    PROCEDURE FileNewItemClick(Sender: TObject);
    PROCEDURE WindowCascadeItemClick(Sender: TObject);
    PROCEDURE UpdateMenuItems(Sender: TObject);
    PROCEDURE WindowTileItemClick(Sender: TObject);
    PROCEDURE WindowArrangeItemClick(Sender: TObject);
    PROCEDURE FileCloseItemClick(Sender: TObject);
    PROCEDURE FileOpenItemClick(Sender: TObject);
    PROCEDURE FileExitItemClick(Sender: TObject);
    PROCEDURE FileSaveItemClick(Sender: TObject);
    PROCEDURE WindowMinimizeItemClick(Sender: TObject);
    PROCEDURE FormDestroy(Sender: TObject);
    PROCEDURE SpeedButtonPFNodeClick(Sender: TObject);
    PROCEDURE SpeedButtonPFWireClick(Sender: TObject);
    PROCEDURE SpeedButtonLtgClick(Sender: TObject);
    PROCEDURE SpeedButtonZLClick(Sender: TObject);
    PROCEDURE SpeedButtonQuelleClick(Sender: TObject);
    PROCEDURE FileSaveAsItemClick(Sender: TObject);
    PROCEDURE HelpAboutItemClick(Sender: TObject);
    PROCEDURE Contents1Click(Sender: TObject);
  PRIVATE
    PROCEDURE CreateMDIChild(const Name: string);
    PROCEDURE ShowHint(Sender: TObject);
  PUBLIC
  PUBLISHED
  END;

VAR
  MDIMainForm: TMDIMainForm;

IMPLEMENTATION

USES
  SubChild, ChildWin;

{$R *.DFM}
(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.FormCreate(Sender: TObject);

VAR
  strIniFile	: TFileName;

BEGIN
Application.OnHint := ShowHint;
Screen.OnActiveFormChange := UpdateMenuItems;

strIniFile	:= ParamStr(0);
Delete( strIniFile, Pos('.',strIniFile)+1, 3);
strIniFile	:= strIniFile+'INI';

WITH INIProfile, MDIMainForm DO
  BEGIN
  INIProfile.Action	:= paRead;
  IniFileName	:= strIniFile;
  Category	:= Application.Title;

  KeyName	:= 'Left';
  DefaultValue	:= IntToStr( Left );
  Execute;
  Left		:= StrToInt( DataString );

  KeyName	:= 'Top';
  DefaultValue	:= IntToStr( Top );
  Execute;
  Top		:= StrToInt( DataString );

  KeyName	:= 'Width';
  DefaultValue	:= IntToStr( Width );
  Execute;
  Width		:= StrToInt( DataString );

  KeyName	:= 'Height';
  DefaultValue	:= IntToStr( Height );
  Execute;
  Height	:= StrToInt( DataString );

  KeyName       := 'IDirectory';
  DefaultValue	:= GetCurrentDir;
  Execute;
  SetCurrentDir( DataString );
  END;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.ShowHint(Sender: TObject);

BEGIN
StatusBar.SimpleText := Application.Hint;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.CreateMDIChild(const Name: string);

VAR
  Child: TMDIChild;

BEGIN
Child              := TMDIChild.CreateExtra( Application, Name, Point( 200, 200 ) );
Child.Caption      := ExtractFileName( Name );
StatusBar.Panels[3].Text := 'File '+Child.Caption+' open!';
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.FileNewItemClick(Sender: TObject);

BEGIN
CreateMDIChild('NONAME' + IntToStr(MDIChildCount + 1)+'.RPC');
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.FileOpenItemClick(Sender: TObject);

VAR
  i            : INTEGER;
  aOpenDialog  : TOpenDialog;
  bAlreadyOpen : BOOLEAN;

BEGIN
aOpenDialog	:=  TOpenDialog.Create( MDIMainForm );
WITH aOpenDialog DO
  BEGIN
  DefaultExt	:= 'RPC';
  Options	:= [ofPathMustExist,ofFileMustExist,ofNoReadOnlyReturn];
  Filter	:= 'CAN network|*.rpc';
  InitialDir	:= GetCurrentDir;
  IF Execute THEN
    BEGIN
    bAlreadyOpen := false;
    FOR i := MDIChildCount-1 DOWNTO 0 DO
      IF ExtractFileName(MDIChildren[i].Caption) = ExtractFileName(FileName) THEN
        bAlreadyOpen := true;
    IF bAlreadyOpen THEN
      BEGIN
      Application.MessageBox( PChar('File '+FileName+' already open'), 'File open error', mb_OK + mb_DefButton1 + mb_IconInformation);
      StatusBar.Panels[3].Text := 'File '+FileName+' already open!';
      END
     ELSE
      BEGIN
      CreateMDIChild( FileName );
      END;
    END;
  END;
aOpenDialog.Free;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.FileCloseItemClick(Sender: TObject);

VAR
  i: INTEGER;
  strFileName: TFileName;

BEGIN
IF ActiveMDIChild IS TMDIChild THEN
  BEGIN
  TMDIChild(ActiveMDIChild).Close
  END
 ELSE
  BEGIN
  strFileName := ExtractFileName( ActiveMDIChild.Caption );
  FOR i := MDIChildCount-1 DOWNTO 0 DO
    IF (MDIChildren[i] IS TMDIChild) AND (MDIChildren[I].Caption = strFileName) THEN
      MDIChildren[i].Close;
  END;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.FileSaveItemClick(Sender: TObject);

VAR
  strFileName  : TFileName;
  i            : INTEGER;

BEGIN
IF ActiveMDIChild IS TSubForm THEN
  BEGIN
  strFileName := TSubForm(ActiveMDIChild).SaveCAN
  END
 ELSE
  BEGIN
  strFileName := ExtractFileName( ActiveMDIChild.Caption );
  FOR i := MDIChildCount-1 DOWNTO 0 DO
    IF (MDIChildren[i] IS TSubForm) AND (ExtractFileName(MDIChildren[I].Caption) = strFileName) THEN
      strFileName := TSubForm(MDIChildren[i]).SaveCAN;
  END;
IF Length(strFileName) > 0 THEN StatusBar.Panels[3].Text := 'File '+strFileName+' saved';
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.FileSaveAsItemClick(Sender: TObject);

VAR
  aFileName   : TFileName;
  strFileName : TFileName;
  i           : INTEGER;

BEGIN
aFileName   := '';
IF ActiveMDIChild IS TSubForm THEN
  BEGIN
  aFileName := TSubForm(ActiveMDIChild).SaveCANAs( Self );
  END
 ELSE
  BEGIN
  strFileName := ExtractFileName( ActiveMDIChild.Caption );
  FOR i := MDIChildCount-1 DOWNTO 0 DO
    IF (MDIChildren[i] IS TSubForm) AND (ExtractFileName(MDIChildren[I].Caption) = strFileName) THEN
      aFileName := TSubForm(MDIChildren[i]).SaveCANAs( Self );
  END;
IF Length(aFileName) > 0 THEN StatusBar.Panels[3].Text := 'File '+aFileName+' saved';
END;
(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.FileExitItemClick(Sender: TObject);

BEGIN
Close;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.WindowCascadeItemClick(Sender: TObject);

BEGIN
Cascade;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.WindowTileItemClick(Sender: TObject);

BEGIN
Tile;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.WindowArrangeItemClick(Sender: TObject);

BEGIN
ArrangeIcons;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.WindowMinimizeItemClick(Sender: TObject);

VAR
  i: INTEGER;

BEGIN
FOR i := MDIChildCount - 1 DOWNTO 0 DO
  MDIChildren[i].WindowState := wsMinimized;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.UpdateMenuItems(Sender: TObject);

BEGIN
FileCloseItem.Enabled      := MDIChildCount > 0;
FileSaveItem.Enabled       := MDIChildCount > 0;
FileSaveAsItem.Enabled     := MDIChildCount > 0;
SaveBtn.Enabled            := MDIChildCount > 0;
WindowCascadeItem.Enabled  := MDIChildCount > 0;
WindowTileItem.Enabled     := MDIChildCount > 0;
WindowArrangeItem.Enabled  := MDIChildCount > 0;
WindowMinimizeItem.Enabled := MDIChildCount > 0;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.FormDestroy(Sender: TObject);

BEGIN
Screen.OnActiveFormChange := nil;
WITH INIProfile, MDIMainForm DO
  BEGIN
  INIProfile.Action	:= paWrite;
  Category	:= Application.Title;

  KeyName	:= 'Left';
  DefaultValue	:= IntToStr( Left );
  DataString	:= DefaultValue;
  Execute;

  KeyName	:= 'Top';
  DefaultValue	:= IntToStr( Top );
  DataString	:= DefaultValue;
  Execute;

  KeyName	:= 'Width';
  DefaultValue	:= IntToStr( Width );
  DataString	:= DefaultValue;
  Execute;

  KeyName	:= 'Height';
  DefaultValue	:= IntToStr( Height );
  DataString	:= DefaultValue;
  Execute;

  KeyName       := 'IDirectory';
  DefaultValue	:= GetCurrentDir;
  DataString	:= DefaultValue;
  Execute;
  END;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.SpeedButtonPFNodeClick(Sender: TObject);

BEGIN
IF ActiveMDIChild IS TSubForm THEN
  WITH TSubForm(ActiveMDIChild), SpeedButtonPFNode DO
    IF Down THEN FMode := mGetNode ELSE FMode := mNone;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.SpeedButtonPFWireClick(Sender: TObject);

BEGIN
IF ActiveMDIChild IS TSubForm THEN
  WITH TSubForm(ActiveMDIChild), SpeedButtonPFWire DO
    IF Down THEN FMode := mGetWire ELSE FMode := mNone;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.SpeedButtonLtgClick(Sender: TObject);

BEGIN
IF ActiveMDIChild IS TSubForm THEN
  WITH TSubForm(ActiveMDIChild), SpeedButtonLtg DO
    IF Down THEN FMode := mDrawTRMLine ELSE FMode := mNone;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.SpeedButtonZLClick(Sender: TObject);

BEGIN
IF ActiveMDIChild IS TSubForm THEN
  WITH TSubForm(ActiveMDIChild), SpeedButtonZL DO
    IF Down THEN FMode := mPlaceZL ELSE FMode := mNone;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.SpeedButtonQuelleClick(Sender: TObject);

BEGIN
IF ActiveMDIChild IS TSubForm THEN
  WITH TSubForm(ActiveMDIChild), SpeedButtonQuelle DO
    IF Down THEN FMode := mPlaceSrc ELSE FMode := mNone;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.HelpAboutItemClick(Sender: TObject);

BEGIN
AboutBox  := TAboutBox.Create( Application );
AboutBox.ShowModal;
AboutBox.Free;
END;

(*------------------------------------------------------*)
PROCEDURE TMDIMainForm.Contents1Click(Sender: TObject);

BEGIN
WinHelp( Handle, PChar(Application.HelpFile), Help_Index, 0 );
END;

(*++++++++++++++++++++++++++++++++++++++++++++++++++++++*)
END.
